==> wc-buckaroo-bpe-gateway.3.0.0.zip: wc-buckaroo-bpe-gateway-master/library/api/paymentmethods/buckaroopaypal/paypalresponse.php <==
<?php

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

require_once(dirname(__FILE__) . '/../response.php');

/**
 * @package Buckaroo
 */
class BuckarooPayPalResponse extends BuckarooResponse {
    public $payerEmail;
    public $payerCountry;
    public $payerStatus;
    public $payerFirstname;
    public $payerLastname;
    public $paypalTransactionID;

    /**
     * @access protected
     */
    protected function _parseSoapResponseChild() {
        $this->payerEmail = '';
        $this->payerCountry = '';
        $this->payerStatus = '';
        $this->payerFirstname = '';
        $this->payerLastname = '';
        $this->paypalTransactionID = '';
    }

    /**
     * @access protected
     */
    protected function _parsePostResponseChild() {
        if (isset($_POST['brq_service_paypal_payerEmail'])) {
            $this->payerEmail = $_POST['brq_service_paypal_payerEmail'];
        }
        if (isset($_POST['brq_service_paypal_payerCountry'])) {
            $this->payerCountry = $_POST['brq_service_paypal_payerCountry'];
        }
        if (isset($_POST['brq_service_paypal_payerStatus'])) {
            $this->payerStatus = $_POST['brq_service_paypal_payerStatus'];
        }
        if (isset($_POST['brq_service_paypal_payerFirstname'])) {
            $this->payerFirstname = $_POST['brq_service_paypal_payerFirstname'];
        }
        if (isset($_POST['brq_service_paypal_payerLastname'])) {
            $this->payerLastname = $_POST['brq_service_paypal_payerLastname'];
        }
        if (isset($_POST['brq_service_paypal_paypalTransactionID'])) {
            $this->paypalTransactionID = $_POST['brq_service_paypal_paypalTransactionID'];
        }
    }

}

?>

==> wc-buckaroo-bpe-gateway.3.2.0.zip: wc-buckaroo-bpe-gateway-master/library/api/paymentmethods/buckaroopaypal/paypalresponse.php <==
<?php

/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

require_once(dirname(__FILE__) . '/../response.php');

/**
 * @package Buckaroo
 */
class BuckarooPayPalResponse extends BuckarooResponse {
    public $payerEmail;
    public $payerCountry;
    public $payerStatus;
    public $payerFirstname;
    public $payerLastname;
    public $paypalTransactionID;

    /**
     * @access protected
     */
    protected function _parseSoapResponseChild() {
        $this->payerEmail = '';
        $this->payerCountry = '';
        $this->payerStatus = '';
        $this->payerFirstname = '';
        $this->payerLastname = '';
        $this->paypalTransactionID = '';
    }

    /**
     * @access protected
     */
    protected function _parsePostResponseChild() {
        if (isset($_POST['brq_service_paypal_payerEmail'])) {
            $this->payerEmail = $this->_setPostVariable('brq_service_paypal_payerEmail');
        }
        if (isset($_POST['brq_service_paypal_payerCountry'])) {
            $this->payerCountry = $this->_setPostVariable('brq_service_paypal_payerCountry');
        }
        if (isset($_POST['brq_service_paypal_payerStatus'])) {
            $this->payerStatus = $this->_setPostVariable('brq_service_paypal_payerStatus');
        }
        if (isset($_POST['brq_service_paypal_payerFirstname'])) {
            $this->payerFirstname = $this->_setPostVariable('brq_service_paypal_payerFirstname');
        }
        if (isset($_POST['brq_service_paypal_payerLastname'])) {
            $this->payerLastname = $this->_setPostVariable('brq_service_paypal_payerLastname');
        }
        if (isset($_POST['brq_service_paypal_paypalTransactionID'])) {
            $this->paypalTransactionID = $this->_setPostVariable('brq_service_paypal_paypalTransactionID');
        }
    }

}

?>
